@@ -20,6 +20,7 @@
  *
  */
 
+
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -44,7 +45,6 @@
 #define d(x) x
 #define w(x)
 
-extern int gmime_interfaces_utf8;
 
 static unsigned char tohex[16] = {
 	'0', '1', '2', '3', '4', '5', '6', '7',
@@ -138,7 +138,7 @@ rfc2184_decode (const char *in, size_t len)
 	inptr++;
 	if (inptr < inend) {
 		len = inend - inptr;
-		if (gmime_interfaces_utf8 && strcasecmp (charset, "UTF-8") != 0) {
+		if (strcasecmp (charset, "UTF-8") != 0) {
 			char *udecoded;
 			iconv_t cd;
 			
@@ -360,7 +360,6 @@ decode_param (const char **in, char **paramp, char **valuep, gboolean *is_rfc218
 {
 	gboolean is_rfc2184_encoded = FALSE;
 	gboolean is_rfc2184 = FALSE;
-	gboolean valid_utf8 = FALSE;
 	const char *inptr = *in;
 	char *param, *value = NULL;
 	int rfc2184_part = -1;
@@ -385,7 +384,6 @@ decode_param (const char **in, char **paramp, char **valuep, gboolean *is_rfc218
 				
 				val = rfc2184_decode (value, strlen (value));
 				if (val) {
-					valid_utf8 = TRUE;
 					g_free (value);
 					value = val;
 				}
@@ -404,17 +402,13 @@ decode_param (const char **in, char **paramp, char **valuep, gboolean *is_rfc218
 			
 			val = g_mime_utils_8bit_header_decode (value);
 			if (val) {
-				valid_utf8 = TRUE;
 				g_free (value);
 				value = val;
 			}
-		} else {
-			if (gmime_interfaces_utf8)
-				valid_utf8 = !g_mime_utils_text_is_8bit (value, strlen (value));
 		}
 	}
 	
-	if (gmime_interfaces_utf8 && value && !valid_utf8) {
+	if (value && !g_utf8_validate (value, -1, NULL)) {
 		/* A (broken) mailer has sent us an unencoded 8bit value.
 		 * Attempt to save it by assuming it's in the user's
 		 * locale and converting to UTF-8 */
@@ -649,29 +643,21 @@ encode_param (const unsigned char *in, gboolean *encoded)
 	if (*inptr == '\0')
 		return g_strdup (in);
 	
-	if (*inptr > 127) {
-		if (gmime_interfaces_utf8)
-			charset = g_mime_charset_best (in, strlen (in));
-		else
-			charset = g_mime_charset_locale_name ();
-	}
+	if (*inptr > 127)
+		charset = g_mime_charset_best (in, strlen (in));
 	
 	if (!charset)
 		charset = "iso-8859-1";
 	
-	if (gmime_interfaces_utf8) {
-		if (strcasecmp (charset, "UTF-8") != 0)
-			cd = g_mime_iconv_open (charset, "UTF-8");
-		
-		if (cd == (iconv_t) -1)
-			charset = "UTF-8";
-	}
+	if (strcasecmp (charset, "UTF-8") != 0)
+		cd = g_mime_iconv_open (charset, "UTF-8");
 	
 	if (cd != (iconv_t) -1) {
 		outbuf = g_mime_iconv_strdup (cd, in);
 		g_mime_iconv_close (cd);
 		inptr = outbuf;
 	} else {
+		charset = "UTF-8";
 		inptr = in;
 	}
 	
@@ -725,17 +711,6 @@ g_string_append_len_quoted (GString *out, const char *in, size_t len)
 	g_string_append_c (out, '"');
 }
 
-static void
-g_string_append_len (GString *out, const char *in, size_t len)
-{
-	char *buf;
-	
-	buf = alloca (len + 1);
-	strlcpy (buf, in, len);
-	
-	g_string_append (out, buf);
-}
-
 static void
 param_list_format (GString *out, GMimeParam *param, gboolean fold)
 {
@@ -818,12 +793,11 @@ param_list_format (GString *out, GMimeParam *param, gboolean fold)
 				}
 				
 				g_string_sprintfa (out, "%s*%d%s=", param->name, i++, encoded ? "*" : "");
-				if (encoded || !quote)
-					g_string_append_len (out, inptr, (unsigned) (ptr - inptr));
-				else
-					g_string_append_len_quoted (out, inptr, (unsigned) (ptr - inptr));
 				
-				d(printf ("wrote: %s\n", out->str + here));
+				if (encoded || !quote)
+					g_string_append_len (out, inptr, ptr - inptr);
+				else
+					g_string_append_len_quoted (out, inptr, ptr - inptr);
 				
 				used += (out->len - here);
 				
