@@ -42,7 +42,6 @@
 #include "gmime-charset.h"
 #include "gmime-iconv.h"
 #include "gmime-iconv-utils.h"
-#include "unicode.h"
 
 #define d(x)
 #define w(x) x
@@ -73,8 +72,6 @@
 #define DATE_TOKEN_NON_TIMEZONE_NUMERIC (1 << 6)
 #define DATE_TOKEN_HAS_SIGN             (1 << 7)
 
-/* from gmime.c */
-extern int gmime_interfaces_utf8;
 
 static char *base64_alphabet =
 "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
@@ -495,9 +492,9 @@ parse_rfc822_date (struct _date_token *tokens, int *tzone)
 	}
 	
 	t = mktime (&tm);
-#if defined (HAVE_TIMEZONE)
+#if defined(HAVE_TIMEZONE)
 	t -= timezone;
-#elif defined (HAVE_TM_GMTOFF)
+#elif defined(HAVE_TM_GMTOFF)
 	t += tm.tm_gmtoff;
 #else
 #error Neither HAVE_TIMEZONE nor HAVE_TM_GMTOFF defined. Rerun autoheader, autoconf, etc.
@@ -531,7 +528,7 @@ parse_broken_date (struct _date_token *tokens, int *tzone)
 	int hour, min, sec, offset, n;
 	struct _date_token *token;
 	struct tm tm;
-	time_t t;
+	time_t time;
 	
 	memset ((void *) &tm, 0, sizeof (struct tm));
 	got_wday = got_month = got_tzone = FALSE;
@@ -541,7 +538,7 @@ parse_broken_date (struct _date_token *tokens, int *tzone)
 	while (token) {
 		if (is_weekday (token) && !got_wday) {
 			if ((n = get_wday (token->start, token->len)) != -1) {
-				d(printf ("weekday; "));
+				printf ("weekday; ");
 				got_wday = TRUE;
 				tm.tm_wday = n;
 				goto next_token;
@@ -550,7 +547,7 @@ parse_broken_date (struct _date_token *tokens, int *tzone)
 		
 		if (is_month (token) && !got_month) {
 			if ((n = get_month (token->start, token->len)) != -1) {
-				d(printf ("month; "));
+				printf ("month; ");
 				got_month = TRUE;
 				tm.tm_mon = n;
 				goto next_token;
@@ -559,7 +556,7 @@ parse_broken_date (struct _date_token *tokens, int *tzone)
 		
 		if (is_time (token) && !tm.tm_hour && !tm.tm_min && !tm.tm_sec) {
 			if (get_time (token->start, token->len, &hour, &min, &sec)) {
-				d(printf ("time; "));
+				printf ("time; ");
 				tm.tm_hour = hour;
 				tm.tm_min = min;
 				tm.tm_sec = sec;
@@ -571,7 +568,7 @@ parse_broken_date (struct _date_token *tokens, int *tzone)
 			struct _date_token *t = token;
 			
 			if ((n = get_tzone (&t)) != -1) {
-				d(printf ("tzone; "));
+				printf ("tzone; ");
 				got_tzone = TRUE;
 				offset = n;
 				goto next_token;
@@ -581,23 +578,23 @@ parse_broken_date (struct _date_token *tokens, int *tzone)
 		if (is_numeric (token)) {
 			if (token->len == 4 && !tm.tm_year) {
 				if ((n = get_year (token->start, token->len)) != -1) {
-					d(printf ("year; "));
+					printf ("year; ");
 					tm.tm_year = n - 1900;
 					goto next_token;
 				}
 			} else {
 				if (!got_month && !got_wday && token->next && is_numeric (token->next)) {
-					d(printf ("mon; "));
+					printf ("mon; ");
 					n = decode_int (token->start, token->len);
 					got_month = TRUE;
 					tm.tm_mon = n - 1;
 					goto next_token;
 				} else if (!tm.tm_mday && (n = get_mday (token->start, token->len)) != -1) {
-					d(printf ("mday; "));
+					printf ("mday; ");
 					tm.tm_mday = n;
 					goto next_token;
 				} else if (!tm.tm_year) {
-					d(printf ("2-digit year; "));
+					printf ("2-digit year; ");
 					n = get_year (token->start, token->len);
 					tm.tm_year = n - 1900;
 					goto next_token;
@@ -605,20 +602,20 @@ parse_broken_date (struct _date_token *tokens, int *tzone)
 			}
 		}
 		
-		d(printf ("???; "));
+		printf ("???; ");
 		
 	next_token:
 		
 		token = token->next;
 	}
 	
-	d(printf ("\n"));
-	
-	t = mktime (&tm);
-#if defined (HAVE_TIMEZONE)
-	t -= timezone;
-#elif defined (HAVE_TM_GMTOFF)
-	t += tm.tm_gmtoff;
+	printf ("\n");
+		
+	time = mktime (&tm);
+#if defined(HAVE_TIMEZONE)
+	time -= timezone;
+#elif defined(HAVE_TM_GMTOFF)
+	time += tm.tm_gmtoff;
 #else
 #error Neither HAVE_TIMEZONE nor HAVE_TM_GMTOFF defined. Rerun autoheader, autoconf, etc.
 #endif
@@ -626,12 +623,12 @@ parse_broken_date (struct _date_token *tokens, int *tzone)
 	/* t is now GMT of the time we want, but not offset by the timezone ... */
 	
 	/* this should convert the time to the GMT equiv time */
-	t -= ((offset / 100) * 60 * 60) + (offset % 100) * 60;
+	time -= ((offset / 100) * 60 * 60) + (offset % 100) * 60;
 	
 	if (tzone)
 		*tzone = offset;
 	
-	return t;
+	return time;
 }
 
 #if 0
@@ -714,18 +711,6 @@ g_mime_utils_header_decode_date (const char *in, int *saveoffset)
 }
 
 
-static void
-g_string_append_len (GString *out, const char *in, size_t len)
-{
-	char *buf;
-	
-	buf = alloca (len + 1);
-	strlcpy (buf, in, len + 1);
-	
-	g_string_append (out, buf);
-}
-
-
 /**
  * g_mime_utils_header_fold:
  * @in: input header string
@@ -937,7 +922,7 @@ g_mime_utils_unquote_string (char *string)
  * Determines if @text contains 8bit characters within the first @len
  * bytes.
  *
- * Returns TRUE if the text contains 8bit characters or FALSE
+ * Returns %TRUE if the text contains 8bit characters or %FALSE
  * otherwise.
  **/
 gboolean
@@ -964,7 +949,7 @@ g_mime_utils_text_is_8bit (const unsigned char *text, size_t len)
  * Determines the best content encoding for the first @len bytes of
  * @text.
  *
- * Returns a GMimePartEncodingType that is determined to be the best
+ * Returns a #GMimePartEncodingType that is determined to be the best
  * encoding type for the specified block of text. ("best" in this
  * particular case means best compression)
  **/
@@ -1028,6 +1013,11 @@ rfc2047_decode_word (const unsigned char *in, size_t inlen)
 {
 	const register unsigned char *inptr;
 	const unsigned char *inend;
+	const char *charset;
+	unsigned char *buf;
+	char *charenc, *p;
+	size_t len;
+	iconv_t cd;
 	
 	inptr = in + 2;
 	inend = in + inlen - 2;
@@ -1064,57 +1054,47 @@ rfc2047_decode_word (const unsigned char *in, size_t inlen)
 			return NULL;
 		}
 		
-		if (gmime_interfaces_utf8) {
-			const char *charset;
-			unsigned char *buf;
-			char *charenc, *p;
-			size_t len;
-			iconv_t cd;
-			
-			len = (inptr - 3) - (in + 2);
-			charenc = alloca (len + 1);
-			memcpy (charenc, in + 2, len);
-			charenc[len] = '\0';
-			charset = charenc;
-			
-			/* rfc2231 updates rfc2047 encoded words...
-			 * The ABNF given in RFC 2047 for encoded-words is:
-			 *   encoded-word := "=?" charset "?" encoding "?" encoded-text "?="
-			 * This specification changes this ABNF to:
-			 *   encoded-word := "=?" charset ["*" language] "?" encoding "?" encoded-text "?="
-			 */
-			
-			/* trim off the 'language' part if it's there... */
-			p = strchr (charset, '*');
-			if (p)
-				*p = '\0';
-			
-			/* slight optimization */
-			if (!strcasecmp (charset, "UTF-8"))
-				return g_strndup (decoded, declen);
-			
-			cd = g_mime_iconv_open ("UTF-8", charset);
-			if (cd == (iconv_t) -1) {
-				w(g_warning ("Cannot convert from %s to UTF-8, header display may "
-					     "be corrupt: %s", charset, g_strerror (errno)));
-				charset = g_mime_charset_locale_name ();
-				cd = g_mime_iconv_open ("UTF-8", charset);
-				if (cd == (iconv_t) -1)
-					return NULL;
-			}
-			
-			buf = g_mime_iconv_strndup (cd, decoded, declen);
-			g_mime_iconv_close (cd);
-			
-			if (!buf) {
-				w(g_warning ("Failed to convert \"%.*s\" to UTF-8, display may be "
-					     "corrupt: %s", declen, decoded, g_strerror (errno)));
-			}
-			
-			return buf;
-		} else {
+		len = (inptr - 3) - (in + 2);
+		charenc = alloca (len + 1);
+		memcpy (charenc, in + 2, len);
+		charenc[len] = '\0';
+		charset = charenc;
+		
+		/* rfc2231 updates rfc2047 encoded words...
+		 * The ABNF given in RFC 2047 for encoded-words is:
+		 *   encoded-word := "=?" charset "?" encoding "?" encoded-text "?="
+		 * This specification changes this ABNF to:
+		 *   encoded-word := "=?" charset ["*" language] "?" encoding "?" encoded-text "?="
+		 */
+		
+		/* trim off the 'language' part if it's there... */
+		p = strchr (charset, '*');
+		if (p)
+			*p = '\0';
+		
+		/* slight optimization */
+		if (!strcasecmp (charset, "UTF-8"))
 			return g_strndup (decoded, declen);
+		
+		cd = g_mime_iconv_open ("UTF-8", charset);
+		if (cd == (iconv_t) -1) {
+			w(g_warning ("Cannot convert from %s to UTF-8, header display may "
+				     "be corrupt: %s", charset, g_strerror (errno)));
+			charset = g_mime_charset_locale_name ();
+			cd = g_mime_iconv_open ("UTF-8", charset);
+			if (cd == (iconv_t) -1)
+				return NULL;
 		}
+		
+		buf = g_mime_iconv_strndup (cd, decoded, declen);
+		g_mime_iconv_close (cd);
+		
+		if (!buf) {
+			w(g_warning ("Failed to convert \"%.*s\" to UTF-8, display may be "
+				     "corrupt: %s", declen, decoded, g_strerror (errno)));
+		}
+		
+		return buf;
 	}
 	
 	return NULL;
@@ -1278,21 +1258,20 @@ rfc2047_encode_word (GString *string, const unsigned char *word, size_t len,
 	int save = 0;
 	char encoding;
 	
-	if (gmime_interfaces_utf8) {
-		if (strcasecmp (charset, "UTF-8") != 0)
-			cd = g_mime_iconv_open (charset, "UTF-8");
-		
-		if (cd != (iconv_t) -1) {
-			uword = g_mime_iconv_strndup (cd, word, len);
-			g_mime_iconv_close (cd);
-		}
-		
-		if (uword) {
-			len = strlen (uword);
-			word = uword;
-		} else {
-			charset = "UTF-8";
-		}
+	
+	if (strcasecmp (charset, "UTF-8") != 0)
+		cd = g_mime_iconv_open (charset, "UTF-8");
+	
+	if (cd != (iconv_t) -1) {
+		uword = g_mime_iconv_strndup (cd, word, len);
+		g_mime_iconv_close (cd);
+	}
+	
+	if (uword) {
+		len = strlen (uword);
+		word = uword;
+	} else {
+		charset = "UTF-8";
 	}
 	
 	switch (g_mime_utils_best_encoding (word, len)) {
@@ -1353,12 +1332,8 @@ g_mime_utils_8bit_header_encode_phrase (const unsigned char *in)
 	
 	len = strlen (in);
 	
-	if (gmime_interfaces_utf8) {
-		charset = g_mime_charset_best (in, len);
-		charset = charset ? charset : "iso-8859-1";
-	} else {
-		charset = g_mime_charset_locale_name ();
-	}
+	charset = g_mime_charset_best (in, len);
+	charset = charset ? charset : "iso-8859-1";
 	
 	string = g_string_new ("");
 	
@@ -1409,29 +1384,20 @@ rfc2047_encode_phrase_get_words (const unsigned char *in)
 	
 	last = start = inptr = in;
 	while (inptr && *inptr) {
-		gboolean is_space;
-		unichar c;
+		const char *newinptr;
+		gunichar c;
 		
-		if (gmime_interfaces_utf8) {
-			const char *newinptr;
-			
-			newinptr = unicode_next_char (inptr);
-			c = unicode_get_char (inptr);
-			if (newinptr == NULL || !unichar_validate (c)) {
-				w(g_warning ("Invalid UTF-8 sequence encountered"));
-				inptr++;
-				continue;
-			}
-			
-			inptr = newinptr;
-			
-			is_space = unichar_isspace (c);
-		} else {
-			is_space = isspace ((int) *inptr);
-			c = *inptr++;
+		newinptr = g_utf8_next_char (inptr);
+		c = g_utf8_get_char (inptr);
+		if (newinptr == NULL || !g_unichar_validate (c)) {
+			w(g_warning ("Invalid UTF-8 sequence encountered"));
+			inptr++;
+			continue;
 		}
 		
-		if (is_space) {
+		inptr = newinptr;
+		
+		if (g_unichar_isspace (c)) {
 			if (count > 0) {
 				word = g_new (struct _phrase_word, 1);
 				word->next = NULL;
@@ -1572,7 +1538,7 @@ rfc2047_encode_phrase (const unsigned char *in)
 				start = word->start;
 			}
 			
-			if (word->encoding == 1 || !gmime_interfaces_utf8)
+			if (word->encoding == 1)
 				rfc2047_encode_word (out, start, len, "iso-8859-1", IS_PSAFE);
 			else
 				rfc2047_encode_word (out, start, len,
@@ -1619,8 +1585,8 @@ g_mime_utils_8bit_header_encode (const unsigned char *in)
  * @save: leftover bits that have not yet been encoded
  *
  * Base64 encodes the input stream to the output stream. Call this
- * when finished encoding data with g_mime_utils_base64_encode_step to
- * flush off the last little bit.
+ * when finished encoding data with #g_mime_utils_base64_encode_step
+ * to flush off the last little bit.
  *
  * Returns the number of bytes encoded.
  **/
@@ -1746,6 +1712,7 @@ g_mime_utils_base64_encode_step (const unsigned char *in, size_t inlen, unsigned
 	return (outptr - out);
 }
 
+
 /**
  * g_mime_utils_base64_decode_step:
  * @in: input stream
@@ -1819,7 +1786,7 @@ g_mime_utils_base64_decode_step (const unsigned char *in, size_t inlen, unsigned
  * @save: leftover bits that have not yet been encoded
  *
  * Uuencodes a chunk of data. Call this when finished encoding data
- * with g_mime_utils_uuencode_step to flush off the last little bit.
+ * with #g_mime_utils_uuencode_step to flush off the last little bit.
  *
  * Returns the number of bytes encoded.
  **/
@@ -1971,7 +1938,7 @@ g_mime_utils_uuencode_step (const unsigned char *in, size_t inlen, unsigned char
 /**
  * g_mime_utils_uudecode_step:
  * @in: input stream
- * @inlen: max length of data to decode (normally strlen (in) ??)
+ * @inlen: max length of data to decode
  * @out: output stream
  * @state: holds the number of bits that are stored in @save
  * @save: leftover bits that have not yet been decoded
@@ -2080,8 +2047,8 @@ g_mime_utils_uudecode_step (const unsigned char *in, size_t inlen, unsigned char
  * @save: leftover bits that have not yet been encoded
  *
  * Quoted-printable encodes a block of text. Call this when finished
- * encoding data with g_mime_utils_quoted_encode_step to flush off the
- * last little bit.
+ * encoding data with #g_mime_utils_quoted_encode_step to flush off
+ * the last little bit.
  *
  * Returns the number of bytes encoded.
  **/
