@@ -28,8 +28,6 @@
 #include "gmime.h"
 
 
-int gmime_interfaces_utf8 = FALSE;
-
 
 /**
  * g_mime_init:
@@ -47,10 +45,19 @@ g_mime_init (guint32 flags)
 	
 	initialized = TRUE;
 	
-	if (flags & GMIME_INIT_FLAG_UTF8)
-		gmime_interfaces_utf8 = TRUE;
+	g_type_init ();
 	
 	g_mime_charset_init ();
 	
 	g_mime_iconv_init ();
+	
+	/* register our default mime object types */
+	g_mime_object_register_type ("*", "*", g_mime_part_get_type ());
+	g_mime_object_register_type ("multipart", "*", g_mime_multipart_get_type ());
+	g_mime_object_register_type ("multipart", "encrypted", g_mime_multipart_encrypted_get_type ());
+	g_mime_object_register_type ("multipart", "signed", g_mime_multipart_signed_get_type ());
+	g_mime_object_register_type ("message", "rfc822", g_mime_message_part_get_type ());
+	g_mime_object_register_type ("message", "rfc2822", g_mime_message_part_get_type ());
+	g_mime_object_register_type ("message", "news", g_mime_message_part_get_type ());
+	g_mime_object_register_type ("message", "partial", g_mime_message_partial_get_type ());
 }
