@@ -33,12 +33,18 @@
 #include "gmime-data-wrapper.h"
 #include "gmime-object.h"
 #include "gmime-part.h"
+#include "gmime-multipart.h"
+#include "gmime-multipart-encrypted.h"
+#include "gmime-multipart-signed.h"
 #include "gmime-message.h"
+#include "gmime-message-part.h"
+#include "gmime-message-partial.h"
 #include "internet-address.h"
 #include "gmime-parser.h"
 #include "gmime-utils.h"
 #include "gmime-stream.h"
 #include "gmime-stream-buffer.h"
+#include "gmime-stream-cat.h"
 #include "gmime-stream-file.h"
 #include "gmime-stream-filter.h"
 #include "gmime-stream-fs.h"
@@ -51,12 +57,17 @@
 #include "gmime-filter-crlf.h"
 #include "gmime-filter-from.h"
 #include "gmime-filter-html.h"
+#include "gmime-filter-strip.h"
 #include "gmime-filter-yenc.h"
+#include "gmime-exception.h"
+#include "gmime-session.h"
+#include "gmime-cipher-context.h"
+#include "gmime-gpg-context.h"
 
 /* GMIME version */
 static const guint gmime_major_version = 1;
-static const guint gmime_minor_version = 0;
-static const guint gmime_micro_version = 7;
+static const guint gmime_minor_version = 90;
+static const guint gmime_micro_version = 0;
 static const guint gmime_interface_age = 0;
 static const guint gmime_binary_age    = 0;
 
@@ -71,6 +82,10 @@ static const guint gmime_binary_age    = 0;
  * GMIME_INIT_FLAG_UTF8:
  *
  * Initialization flag to enable UTF-8 interfaces throughout GMime.
+ *
+ * Note: this flag is really a no-op and remains only for backward
+ * compatablity. Interfaces will be UTF-8 whether this flag is used or
+ * not.
  **/
 #define GMIME_INIT_FLAG_UTF8  (1 << 0)
 
