@@ -35,6 +35,9 @@
 #include "memchunk.h"
 
 
+/* in glib2, GSearchFunc was combined with GCompareFunc */
+typedef GCompareFunc GSearchFunc;
+
 typedef struct _MemChunkFreeNode {
 	struct _MemChunkFreeNode *next;
 	unsigned int atoms;
